%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.1, (the "License"); you may not use this file except in
%% compliance with the License. You should have received a copy of the
%% Erlang Public License along with this software. If not, it can be
%% retrieved via the world wide web at http://www.erlang.org/.
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Initial Developer of the Original Code is Ericsson Utvecklings AB.
%% Portions created by Ericsson are Copyright 1999, Ericsson Utvecklings
%% AB. All Rights Reserved.''
%% 
%%     $Id: misc_SUITE.erl,v 1.3 2006/01/09 11:49:30 rickard.green Exp $
%%

-module(misc_SUITE).
-export([all/1,init_per_testcase/2,fin_per_testcase/2,init/1,fini/1,
	 fun_arith/1,literal_tests/1]).

-include("test_server.hrl").

all(suite) ->
    [{conf,init,[fun_arith,literal_tests],fini}].

init_per_testcase(Case, Config) ->
    Dog = test_server:timetrap(60),
    [{watchdog,Dog}|Config].

fin_per_testcase(Case, Config) ->
    Dog = ?config(watchdog, Config),
    test_server:timetrap_cancel(Dog),
    ok.

init(Config) when list(Config) ->
    case erlang:system_info(hipe_architecture) of
	undefined -> ok;			%No hipe.
	Other ->
	    ?line PrivDir = ?config(priv_dir, Config),
	    ?line FullPath = code:which(?MODULE),
	    ?line ErlFile = filename:rootname(FullPath) ++ ".erl",
	    ?line c:c(ErlFile, [{outdir,PrivDir},{i,"../"},native]),
	    io:format("module_info/0 returns ~p", [?MODULE:module_info()])
    end,
    ok.

fini(Config) when list(Config) ->
    ok.

fun_arith(Config) when list(Config) ->
    ?line one_free(10),
    ok.

one_free(Iter) ->
    ?line one_free(Iter, fun() -> Iter+1 end).

one_free(0, F) -> ok;
one_free(Iter, F) ->
    11 = F(),
    one_free(Iter-1, F).

literal_tests(Config) when list(Config) ->
    ?line true = literal_tests({}, 0),
    ?line false = literal_tests({}, 1),
    ok.

literal_tests(T, Sz) ->
    case T of
	X when tuple(T), eq == eq, size(T) == Sz -> true;
	X when tuple(T), eq == leq, size(T) =< Sz -> true;
	_ -> false
    end.
